==> kpublictransport-24.08.2-x86_64-1_KDE6.txz: usr/lib64/cmake/KPublicTransport/KPublicTransportTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPublicTransport" for configuration "Release"
set_property(TARGET KPublicTransport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPublicTransport PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KF6::I18nLocaleData"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKPublicTransport.so.24.08.2"
  IMPORTED_SONAME_RELEASE "libKPublicTransport.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransport )
list(APPEND _cmake_import_check_files_for_KPublicTransport "${_IMPORT_PREFIX}/lib64/libKPublicTransport.so.24.08.2" )

# Import target "KPublicTransportOnboard" for configuration "Release"
set_property(TARGET KPublicTransportOnboard APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPublicTransportOnboard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::NetworkManagerQt"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKPublicTransportOnboard.so.24.08.2"
  IMPORTED_SONAME_RELEASE "libKPublicTransportOnboard.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransportOnboard )
list(APPEND _cmake_import_check_files_for_KPublicTransportOnboard "${_IMPORT_PREFIX}/lib64/libKPublicTransportOnboard.so.24.08.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kpublictransport-24.08.3-x86_64-14.1_KDE6.txz: usr/lib64/cmake/KPublicTransport/KPublicTransportTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPublicTransport" for configuration "Release"
set_property(TARGET KPublicTransport APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPublicTransport PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KF6::I18nLocaleData;Qt6::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKPublicTransport.so.24.08.3"
  IMPORTED_SONAME_RELEASE "libKPublicTransport.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransport )
list(APPEND _cmake_import_check_files_for_KPublicTransport "${_IMPORT_PREFIX}/lib64/libKPublicTransport.so.24.08.3" )

# Import target "KPublicTransportOnboard" for configuration "Release"
set_property(TARGET KPublicTransportOnboard APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPublicTransportOnboard PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network;Qt6::Qml;KF6::NetworkManagerQt"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKPublicTransportOnboard.so.24.08.3"
  IMPORTED_SONAME_RELEASE "libKPublicTransportOnboard.so.1"
  )

list(APPEND _cmake_import_check_targets KPublicTransportOnboard )
list(APPEND _cmake_import_check_files_for_KPublicTransportOnboard "${_IMPORT_PREFIX}/lib64/libKPublicTransportOnboard.so.24.08.3" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
